@@ -112,19 +112,18 @@ sub options {
     return $opt;
 }
     
+sub is_windows {
+    unless ( $] < 5.014 ) {
+	if ( eval { require Perl::OSType; } ) { 
+            return Perl::OSType::is_os_type('Windows'); 
+	}
+	diag $@;
+    }
+    return ($^O =~ m{Win}) 
+} 
+
 sub script_name {
-    my $is_windows;
-    if (my $os = eval {
-                     require Perl::OSType; 
-                     Perl::OSType::os_type(); 
-	          } 
-    ) {
-        $is_windows = $os eq 'Windows'
-    }
-    else {
-        $is_windows = ($^O =~ m{Win});
-    }
-    return +($is_windows ? 'file-rename' : 'rename');
+    return +(is_windows() ? 'file-rename' : 'rename');
 }
 
 1;
